summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--lisp/init-eglot.el6
1 files changed, 4 insertions, 2 deletions
diff --git a/lisp/init-eglot.el b/lisp/init-eglot.el
index ed8c284..14ae7a3 100644
--- a/lisp/init-eglot.el
+++ b/lisp/init-eglot.el
@@ -2,10 +2,12 @@
:ensure t
:hook
;; load eglot automatically for these modes
;; go requires gopls: env GO111MODULE=on go get golang.org/x/tools/gopls@latest
;; python requires pyls: python3 -m pip install --user python-language-server
((go-mode . eglot-ensure)
(python-mode . eglot-ensure)
+ (rust-mode . eglot-ensure)
;; format on save
(before-save . eglot-format))
@@ -2,10 +2,12 @@
:hook
;; load eglot automatically for these modes
- ;; go requires gopls: env GO111MODULE=on go get golang.org/x/tools/gopls@latest
- ;; python requires pyls: python3 -m pip install --user python-language-server
+ ;; - go with gopls: env GO111MODULE=on go get -u golang.org/x/tools/gopls@latest
+ ;; - python with pyls: python3 -m pip install --user python-language-server
+ ;; - rust with rls: rustup component add rls
((go-mode . eglot-ensure)
(python-mode . eglot-ensure)